<?php

use yii\helpers\Html;
use yii\grid\GridView;
use yii\widgets\Pjax;
use yii\helpers\Url;
use webvimark\modules\UserManagement\models\User;
use webvimark\modules\UserManagement\UserManagementModule;
use app\models\Apk;

/* @var $this yii\web\View */
/* @var $searchModel app\models\IcSearch */
/* @var $dataProvider yii\data\ActiveDataProvider */

$this->title = 'Apks';
$this->params['breadcrumbs'][] = $this->title;
?>

<?php Pjax::begin(['id' => 'apks-pjax']) ?>
<div class="apk-index">

    <div class="mt-bootstrap-tables">
        <div class="portlet light">
            <?php if (User::hasRole('10')): ?>
                <p>
                    <?= Html::a('Upload APK', ['create'], ['class' => 'btn btn-success']) ?>
                </p>
            <?php endif; ?>

            <div class="portlet-title">
                <div class="caption">
                    <span class="caption-subject font-dark bold uppercase"><?= Html::encode($this->title) ?></span>
                </div>
                <div class="actions">
                    <?= Html::a('Reset Filters', ['index'], ['class' => 'btn btn-default']) ?>
                </div>
            </div>
            
            <div class="portlet-body">
                <div class="table table-scrollable">
                    <?= GridView::widget([
                        'dataProvider' => $dataProvider,
                        'filterModel' => $searchModel,
                        'columns' => [
                            ['class' => 'yii\grid\SerialColumn'],
                            //'apk_version',
                            //'upload_date',
                            [
                                'attribute' => 'apk_version',
                                'contentOptions' => ['class' => 'left-align-column'],
                            ],
                            [
                                'attribute' => 'upload_date',
                                'contentOptions' => ['class' => 'left-align-column'],
                            ],
                            
                            [
                                'class' => 'webvimark\components\StatusColumn',
                                'attribute' => 'status',
                                'optionsArray' => [
                                    [Apk::STATUS_OLD, UserManagementModule::t('back', 'OLDER'), 'default'],
                                    [Apk::STATUS_NEW, UserManagementModule::t('back', 'LATEST'), 'green'],
                                ],
                                
                                'contentOptions' => ['class' => 'status-column'],
                            ],
                            [
                                'attribute' => 'apk_file',
                                'format' => 'raw',
                                'value' => function ($model) {
                                    return Html::a('Download', ['apk-file/download', 'filename' => basename($model->apk_file)], [
                                        'class' => 'btn btn-primary btn-sm',
                                        'data-method' => 'post',
                                    ]);
                                },
                                
                                'contentOptions' => ['class' => 'apk-file-column'],
                            ],
                            [
                                'attribute' => 'download_count',
                                'label' => 'Download Count',
                                'contentOptions' => ['class' => 'left-align-column'],
                            ],
                            // ['class' => 'yii\grid\ActionColumn', 'template' => '{view} {update}'],
                        ],
                    ]); ?>
                </div>
            </div>
        </div>
    </div>
</div>
<?php Pjax::end() ?>

<?php
$this->registerJs("
$(document).on('keyup', '.form-control', function() {
    var form = $('#apks-pjax .filters').closest('form');
    $.pjax.reload({
        container: '#apks-pjax',
        url: form.attr('action'),
        data: form.serialize(),
        timeout: 1000,
    });
});
");
?>

<style>
.status-column {
    vertical-align: middle !important;
}
.apk-file-column {
    display: flex;
    align-items: center;
    justify-content: center;
}
.left-align-column {
    text-align: left !important;
    align-items: center;
}

</style>

