<?php 
use yii\helpers\Url;
use yii\helpers\ArrayHelper;
use yii\widgets\ActiveForm;
use yii\helpers\Html;
use app\models\Region;
use app\models\Ic;
use yii\widgets\Pjax;

$this->params['breadcrumbs'][] = ['label' => 'Cash Collect Summary'];
$this->params['breadcrumbs'][] = $this->title;
\yii\web\YiiAsset::register($this);

?>

<?php Pjax::begin(['id' => 'time-log-pjax']); ?>

<div class="portlet light portlet-fit">
    <div class="row">
        <div class="col-lg-12">
            <div class="portlet light portlet-fit">
                <div class="portlet-title">
                    <div class="caption">
                        <i class="icon-credit-card font-green"></i>
                        <span class="caption-subject font-green bold uppercase">Cash Collect Summary</span>
                    </div>
                    <div class="actions">
                        <?= Html::button('Reset', ['class' => 'btn btn-default', 'onclick' => 'resetForm()']) ?>
                    </div>
                </div>
                <div>
                    <div class="row" style="margin:0px;">
                        <div class="col-md-4">
                            <?php $form = ActiveForm::begin(['id' => 'search-form']); ?>
                            
                            <?= $form->field($model, 'region')->dropDownList(
                                    Region::getRegionWithDefault(),
                                    [
                                        'id' => 'region-dropdown',
                                        'onchange' => '
                                            var regionId = $(this).val();
                                            if (regionId === "") {
                                                $("select#ic-dropdown").html("<option value=\'\'>Select IC</option>");
                                            } else {
                                                $.post(
                                                    "' . Yii::$app->urlManager->createUrl('ic/ic-list?region_id=') . '"+regionId, 
                                                    function(data) {
                                                        $("select#ic-dropdown").html(data);
                                                    }
                                                );
                                            }
                                        ',
                                    ]
                                ); ?> 
                            <?= $form->field($model, 'ic')->dropDownList($icOptions, ['id' => 'ic-dropdown']); ?>

                            <?= Html::submitButton('Search', ['class' => 'btn btn-success']) ?>
                            
                            <?php ActiveForm::end(); ?>
                        </div>
                        <div class="col-md-8" style="text-align: right;">
                            <?php if ($results): ?>
                                <?php foreach ($results as $result): ?>
                                    <div class="shift" id="<?= $result['id']?>" onclick="getSummary('<?= $result['id']?>');">
                                        <span><i style="padding: 3px 7px 0 0;" class="fa fa-tasks"></i></span>
                                        <span>
                                            &nbsp;<?= $result['shift_name']?> | <?= $result['shift_start']?> |
                                            <?= $result['shift_end']?> | <?= $result['ic_id']?>
                                        </span>
                                    </div>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </div>
                    </div>
                    <br>
                    <div class="row" style="margin: auto; width: 98%;">
                        <div id="balance-details" style="display:none;">
                            <div class="actions" style="float:right;">
                                <div class="btn-group">
                                    <a class="btn blue btn-outline btn-circle btn-sm" href="javascript:;" data-toggle="dropdown"
                                        data-hover="dropdown" data-close-others="true" aria-expanded="false"> Export
                                        <i class="fa fa-angle-down"></i>
                                    </a>
                                    <ul class="dropdown-menu pull-right" style="min-width: 80px;">
                                        <li>
                                            <a href="<?php echo Yii::$app->getUrlManager()->getBaseUrl(); ?>/index.php/cash-collect/cash-collect-summary-pdf"
                                                target="_blank"> Pdf </a>
                                        </li>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div>
                        <table id="tbody" class="table tableCompany_View-striped table-bordered table-advance table-hover shift-table">
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<?php Pjax::end(); ?>

<style>
.shift-table {
    max-width: 98% !important;
    margin: auto !important;
}
.shift {
    padding: 4px;
    margin-bottom: 4px;
    cursor: pointer;
    font-size: 12px;
    font-weight: 600;
    display: inline-flex;
    min-width: 400px;
}
</style>

<script>
function getSummary(shift_id) {
    $("#balance-details p").remove();
    $("#tbody tr").remove();
    document.getElementById("balance-details").style.display = "none";
    
    getCashBalance(shift_id);

    var elements = document.getElementsByClassName('shift'); // get all elements
    for (var i = 0; i < elements.length; i++) {
        elements[i].style.backgroundColor = "white";
    }
    document.getElementById(shift_id).style.backgroundColor = "#e2e3e5";

    $.ajax({
        type: 'POST',
        url: '<?php echo Url::to(['cash-collect/get-summary']); ?>',
        data: { shift_id: shift_id },
        success: function(result) {
            $("#tbody tr").remove();
            $("#tbody").append(result);
        },
        error: function(data) {
            alert("You are not authorized to perform this action");
        }
    });
}

function getCashBalance(shift_id) {
    $.ajax({
        type: 'POST',
        url: '<?php echo Url::to(['cash-collect/get-cash-balance']); ?>',
        data: { shift_id: shift_id },
        success: function(result) {
            result = JSON.parse(result);
            var html = "<p style='margin:0px;'>SYSTEM CALCULATED TOTAL AMOUNT :  <span style='font-weight:bold;'>" + result.sysTotal + "</span></p>";
            html += "<p style='margin:0px;'>CASH IN :  <span style='font-weight:bold;'>" + result.cashTotal + "</span></p>";
            if (result.balance < 0) {
                html += "<p style='margin:0px;color: red;'>SHORT : <span style='font-weight:bold;'>" + result.balance + "</span></p>";
            } else if (result.balance > 0) {
                html += "<p style='margin:0px;color: green;'>EXCESS :  <span style='font-weight:bold;'>" + result.balance + "</span></p>";
            } else {
                html += "<p style='margin:0px;color: blue;'>AMOUNT MATCHED : <span style='font-weight:bold;'>" + result.balance + "</span></p>";
            }
            $("#balance-details p").remove();
            $("#balance-details").append(html);
            document.getElementById("balance-details").style.display = "block";
        },
        error: function(data) {
            alert("You are not authorized to perform this action");
        }
    });
}

function resetForm() {
    $('#search-form')[0].reset(); // Reset form fields
    $('#region-dropdown').val('').trigger('change'); // Reset dropdowns
    $('#ic-dropdown').val('').trigger('change'); // Reset dropdowns
    $.pjax.reload({container: '#time-log-pjax', timeout: false}); // Reload Pjax container
}
</script>
