<?php

use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use PhpOffice\PhpSpreadsheet\Style\Border;
use PhpOffice\PhpSpreadsheet\Style\Fill;
use app\models\Ic;
use webvimark\modules\UserManagement\models\User;

// Create a new spreadsheet
$spreadsheet = new Spreadsheet();
$sheet = $spreadsheet->getActiveSheet();
$sheet->setTitle('DUPLICATE TICKET REPORT');

$nowdate = date('Y.m.d.h.i.s');

// Define styles
$styleArrayHeading = [
    'font' => [
        'bold' => true,
        'color' => ['rgb' => '307BBA'],
        'size' => 8,
        'name' => 'Verdana'
    ],
];

$styleArrayBorder = [
    'borders' => [
        'allBorders' => [
            'borderStyle' => Border::BORDER_THIN,
            'color' => ['rgb' => '000000']
        ],
    ],
];

// Set column widths
$headers = ['Entrance Ticket Serial', 'Entrance IC', 'Entrance Time', 'Exit Ticket Serial', 'Exit IC', 'Exit Time', 'Vehicle Category', 'Exit Teller', 'Amount'];
$columns = range('A', 'I');
foreach ($columns as $index => $column) {
    $sheet->getColumnDimension($column)->setWidth(20);
}

// Set header values
$count = 1;
$sheet->setCellValue('A' . $count++, 'DUPLICATE TICKET REPORT');
$sheet->setCellValue('A' . $count++, 'GENERATED DATE: ' . $nowdate);
$sheet->setCellValue('A' . $count++, 'USER: ' . Yii::$app->getUser()->identity->username);
$sheet->setCellValue('A' . $count++, $model['ic'] == 'Any' ? 'IC: Any' : 'IC: ' . Ic::findOne($model['ic'])->name);
$count++;

// Set table headers
$colIndex = 1;
foreach ($headers as $header) {
    $sheet->setCellValueByColumnAndRow($colIndex++, $count, $header);
}
$sheet->getStyle('A' . $count . ':I' . $count)->applyFromArray($styleArrayHeading);
$sheet->getStyle('A' . $count . ':I' . $count)->getFill()
    ->setFillType(Fill::FILL_SOLID)
    ->getStartColor()->setARGB('a3c2c2');

$count++;

// Fill data
foreach ($results as $result) {
    $rowIndex = 1;
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['entrance_serial']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['entrance_ic']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['entrance_time']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['exit_serial']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['exit_ic']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['exit_time']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['vehicle_category']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['teller']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['amount']);
    $count++;
}

// Add duplicate ticket count
$sheet->setCellValue('A' . $count, 'Duplicate Ticket Count');
$sheet->mergeCells('A' . $count . ':H' . $count);
$sheet->setCellValue('I' . $count, $totalDuplicateCount);
$sheet->getStyle('A' . $count . ':I' . $count)->applyFromArray($styleArrayBorder);
$sheet->getStyle('A' . $count . ':I' . $count)->applyFromArray($styleArrayHeading);
$count++;

// Apply border style to data range
$sheet->getStyle('A' . ($count - count($results) - 1) . ':I' . ($count - 1))->applyFromArray($styleArrayBorder);

// Output the Excel file
$filename = 'DUPLICATE_TICKET_REPORT_' . date('Y-m-d-H-i-s') . '.xlsx';
header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
header('Content-Disposition: attachment;filename="' . $filename . '"');
header('Cache-Control: max-age=0');

$writer = new Xlsx($spreadsheet);
$writer->save('php://output');
exit;
?>
