<?php

use yii\helpers\Html;
use yii\grid\GridView;
use yii\widgets\ActiveForm;
use yii\helpers\ArrayHelper;
use yii\helpers\Url;
use yii\bootstrap4\Modal;
use kartik\date\DatePicker;
use app\models\Region;
use app\models\Ic;
use app\models\Designation;
use webvimark\modules\UserManagement\models\User;
use webvimark\modules\UserManagement\models\rbacDB\Role;
use kartik\depdrop\DepDrop;
use yii\widgets\LinkPager;
use yii\helpers\Json;
use yii\widgets\Pjax;
use kartik\select2\Select2;
use kartik\datetime\DateTimePicker;

/* @var $this yii\web\View */
/* @var $searchModel app\models\TimeLogSearch */
/* @var $dataProvider yii\data\ActiveDataProvider */

$this->title = 'Inactive Entrance Ic - Exit Ticket Report';
$this->params['breadcrumbs'][] = $this->title;
?>

<div class="time-log-index">

<?php Pjax::begin(['id' => 'time-log-pjax']); ?>

   
<?php $form = ActiveForm::begin(['id' => 'search-form']);?>

    <div class="mt-bootstrap-tables">
        <div>
            <div class="portlet light ">

                <div class="portlet-title">
                    <div class="caption">
                        <span class="caption-subject font-dark bold uppercase">
                            <?= Html::encode($this->title) ?></span>
                    </div>
                    <div class="actions">
                        <!-- Reset Button -->
                        <?= Html::resetButton('Reset', ['class' => 'btn btn-default', 'onclick' => 'resetForm()']) ?>
                    </div>
                </div>

                <div class="portlet-body" style="margin-top: 26px;">
                    <form role="form">
                        <div class="row">
                            <div class="col-md-1 pull-right">
                                <?= Html::submitButton('Search', ['class' => 'btn btn-success']) ?>
                            </div>
                        </div>
                        
                        <div class="row">
                            <div class="col-md-4">
                                    <?= $form->field($model, 'region')->widget(Select2::classname(), [
                                        'data' => Region::getRegionWithDefault(),
                                        'options' => ['id' => 'region-dropdown', 'prompt' => 'Select Region'],
                                        'pluginOptions' => [
                                            'allowClear' => true,
                                        ],
                                        'pluginEvents' => [
                                            'change' => 'function() {
                                                var regionId = $(this).val();
                                                if (regionId === "") {
                                                    $("select#ic-dropdown").html("<option value=\'\'>Select IC</option>");
                                                } else {
                                                    $.post(
                                                        "' . Yii::$app->urlManager->createUrl('ic/ic-list?region_id=') . '"+regionId, 
                                                        function(data) {
                                                            $("select#ic-dropdown").html(data);
                                                        }
                                                    );
                                                }
                                            }'
                                        ],
                                    ]); ?>
                                </div>
                                <div class="col-md-4">
                                        <?= $form->field($model, 'ic')->widget(Select2::classname(), [
                                            'data' => [],
                                            'options' => [
                                                'id' => 'ic-dropdown',
                                                'prompt' => 'Select IC',
                                            ],
                                            'pluginOptions' => [
                                                'allowClear' => true,
                                            ],
                                        ]); ?>
                                    </div>
                            </div>




                        <div class="row">
                            <div class="col-md-4">
                                <?= $form->field($model, 'startDate')->widget(DateTimePicker::classname(), [
                                    'options' => ['placeholder' => 'Enter Start Date/Time'],
                                    'pluginOptions' => [
                                        'autoclose' => true
                                    ]
                                ]); ?>
                            </div>
                            <div class="col-md-4">
                                <?= $form->field($model, 'endDate')->widget(DateTimePicker::classname(), [
                                    'options' => ['placeholder' => 'Enter End Date/Time'],
                                    'pluginOptions' => [
                                        'autoclose' => true
                                    ]
                                ]); ?>
                            </div>
                        </div>

                        <br>
                        <br>
                    </form>
                </div>
            </div>
        </div>
    </div>
    <?php ActiveForm::end(); ?>

    <?php Pjax::end(); ?>

</div>

<style>
.top-border {
    border-top: 2px solid #cccccc !important;
    border-left: 2px solid #cccccc !important;
    border-right: 2px solid #cccccc !important;
    background-color: #fff3cd;
    padding: 1px !important;
    font-weight: bold;
    text-align: right;
}

.bottom-border {
    border-bottom: 2px solid #cccccc !important;
    border-left: 2px solid #cccccc !important;
    border-right: 2px solid #cccccc !important;
    background-color: #d1ecf1;
    padding: 1px !important;
    text-align: right;
    font-weight: bold;
}

.specific-column {
    background-color: #f5c6cb !important;
    border: 2px solid #cccccc !important;
}

.grand_total {
    text-align: right;
    font-weight: bold;
}

th {
    text-align: center;
}

.my-custom-scrollbar {
    position: relative;
    height: 500px;
    overflow: auto;
}

.table-wrapper-scroll-y {
    display: block;
}

#entranceSearch {
    padding: 5px 5px 5px 5px;
    border: 1px solid #ddd;
    margin: -5px;
    width: -webkit-fill-available;
}
</style>

<script>
    
    function gotoUrl(path, params, method) {
        method = method || "post";

        var form = document.createElement("form");
        form.setAttribute("method", method);
        form.setAttribute("action", path);

        if (typeof params === 'string') {
            var hiddenField = document.createElement("input");
            hiddenField.setAttribute("type", "hidden");
            hiddenField.setAttribute("name", 'data');
            hiddenField.setAttribute("value", params);
            form.appendChild(hiddenField);
        } else {
            for (var key in params) {
                if (params.hasOwnProperty(key)) {
                    var hiddenField = document.createElement("input");
                    hiddenField.setAttribute("type", "hidden");
                    hiddenField.setAttribute("name", key);
                    hiddenField.setAttribute("value", typeof params[key] === 'object' ? JSON.stringify(params[key]) : params[key]);
                    form.appendChild(hiddenField);
                }
            }
        }
        form.target = '_blank';
        document.body.appendChild(form);
        form.submit();
        return false;
    }

    function resetForm() {
        $('#search-form')[0].reset();

        $('#region-dropdown').val('').trigger('change');
        $('#ic-dropdown').val('').trigger('change');
        $('#<?= Html::getInputId($model, 'designation') ?>').val('').trigger('change');
        $('#<?= Html::getInputId($model, 'role') ?>').val('').trigger('change');
        $('#<?= Html::getInputId($model, 'status') ?>').val('').trigger('change');

        $('#results-table').html('');

        $.pjax.reload({container: '#time-log-pjax', async: false});

        location.reload();
    }
</script>
