<?php

use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use PhpOffice\PhpSpreadsheet\Style\Border;
use PhpOffice\PhpSpreadsheet\Style\Fill;
use app\models\Ic;
use webvimark\modules\UserManagement\models\User;

// Create a new spreadsheet
$spreadsheet = new Spreadsheet();
$sheet = $spreadsheet->getActiveSheet();
$sheet->setTitle('INCOMPLETE SESSION REPORT');

$nowdate = date('Y.m.d.h.i.s');

// Define styles
$styleArrayHeading = [
    'font' => [
        'bold' => true,
        'color' => ['rgb' => '307BBA'],
        'size' => 8,
        'name' => 'Verdana'
    ],
];

$styleArrayBorder = [
    'borders' => [
        'allBorders' => [
            'borderStyle' => Border::BORDER_THIN,
            'color' => ['rgb' => '000000']
        ],
    ],
];

// Set column widths
$headers = ['Teller ID', 'Session In (Date/Time)', 'Session Out (Date/Time)', 'Status(Proceed / Not Proceeded)', 'Traffic', 'Amount'];
$columns = range('A', 'G');
foreach ($columns as $index => $column) {
    $sheet->getColumnDimension($column)->setWidth(20);
}

// Set header values
$count = 1;
$sheet->setCellValue('A' . $count++, 'INCOMPLETE SESSION REPORT');
$sheet->setCellValue('A' . $count++, 'GENERATED DATE: ' . $nowdate);
$sheet->setCellValue('A' . $count++, 'USER: ' . Yii::$app->getUser()->identity->username);
$sheet->setCellValue('A' . $count++, $model['ic'] == 'Any' ? 'IC: Any' : 'IC: ' . Ic::findOne($model['ic'])->name);
$count++;

// Set table headers
$colIndex = 1;
foreach ($headers as $header) {
    $sheet->setCellValueByColumnAndRow($colIndex++, $count, $header);
}
$sheet->getStyle('A' . $count . ':G' . $count)->applyFromArray($styleArrayHeading);
$sheet->getStyle('A' . $count . ':G' . $count)->getFill()
    ->setFillType(Fill::FILL_SOLID)
    ->getStartColor()->setARGB('a3c2c2');

$count++;

// Fill data
foreach ($results as $result) {
    $rowIndex = 1;
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['tellerID']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['sessionIn']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['sessionOut']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['status']? 'Proceed' : 'Not Proceeded');
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['traffic']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['amount']);
    $count++;
}

// Apply border style to data range
$sheet->getStyle('A' . ($count - count($results) - 1) . ':I' . ($count - 1))->applyFromArray($styleArrayBorder);

// Output the Excel file
$filename = 'INCOMPLETE_SESSION_REPORT_' . date('Y-m-d-H-i-s') . '.xlsx';
header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
header('Content-Disposition: attachment;filename="' . $filename . '"');
header('Cache-Control: max-age=0');

$writer = new Xlsx($spreadsheet);
$writer->save('php://output');
exit;
?>
