<?php

use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use PhpOffice\PhpSpreadsheet\Style\Border;
use PhpOffice\PhpSpreadsheet\Style\Fill;
use app\models\Ic;
use webvimark\modules\UserManagement\models\User;

// Create a new spreadsheet
$spreadsheet = new Spreadsheet();
$sheet = $spreadsheet->getActiveSheet();
$sheet->setTitle('INCOMPLETE TICKET REPORT');

$nowdate = date('Y.m.d.h.i.s');

// Define styles
$styleArrayHeading = [
    'font' => [
        'bold' => true,
        'color' => ['rgb' => '307BBA'],
        'size' => 8,
        'name' => 'Verdana'
    ],
];

$styleArrayBorder = [
    'borders' => [
        'allBorders' => [
            'borderStyle' => Border::BORDER_THIN,
            'color' => ['rgb' => '000000']
        ],
    ],
];

// Set column widths
$columns = ['A' => 20, 'B' => 20, 'C' => 20, 'D' => 20, 'E' => 20, 'F' => 20, 'G' => 20, 'H' => 20, 'I' => 20];
foreach ($columns as $column => $width) {
    $sheet->getColumnDimension($column)->setWidth($width);
}

// Set header values
$count = 1;

if($model['type'] == "entrance"){
    $sheet->setCellValue('A' . $count++, 'INCOMPLETE TICKET REPORT(Entrance)');
} else {
    $sheet->setCellValue('A' . $count++, 'INCOMPLETE TICKET REPORT(Exit)');
}

$sheet->setCellValue('A' . $count++, 'GENERATED DATE: ' . $nowdate);
$sheet->setCellValue('A' . $count++, 'USER: ' . Yii::$app->getUser()->identity->username);
$sheet->setCellValue('A' . $count++, $model['ic'] == 'Any' ? 'IC: Any' : 'IC: ' . Ic::findOne($model['ic'])->name);
$count++;

// Set table headers
$headers = ['Entrance Serial', 'Entrance Time', 'Exit Serial', 'Exit Time', 'Amount', 'IC', 'Booth', 'Vehicle Category', 'Teller'];
$colIndex = 1;
foreach ($headers as $header) {
    $sheet->setCellValueByColumnAndRow($colIndex++, $count, $header);
}
$sheet->getStyle('A' . $count . ':I' . $count)->applyFromArray($styleArrayHeading);
$sheet->getStyle('A' . $count . ':I' . $count)->getFill()
    ->setFillType(Fill::FILL_SOLID)
    ->getStartColor()->setARGB('a3c2c2');

$count++;

// Fill data
foreach ($results as $result) {
    $rowIndex = 1;
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['entrance_serial']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['entrance_time']);
    if ($model['type'] == 'exit') {
        $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['exit_serial']);
        $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['exit_time']);
        $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['amount']);
    } else {
        $rowIndex += 3; // Skip columns for exit related fields if not applicable
    }
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['ic']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['booth']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['vc']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['teller']);
    $count++;
}

// Apply border style to data range
$sheet->getStyle('A' . ($count - count($results) - 1) . ':I' . ($count - 1))->applyFromArray($styleArrayBorder);

// Output the Excel file
$filename = 'INCOMPLETE_TICKET_REPORT_' . date('Y-m-d-H-i-s') . '.xlsx';
header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
header('Content-Disposition: attachment;filename="' . $filename . '"');
header('Cache-Control: max-age=0');

$writer = new Xlsx($spreadsheet);
$writer->save('php://output');
exit;
?>
