<?php

use yii\helpers\Html;
use yii\grid\GridView;
use yii\widgets\ActiveForm;
use yii\helpers\ArrayHelper;
use yii\helpers\Url;
use yii\bootstrap4\Modal;
use kartik\date\DatePicker;
use app\models\Region;
use app\models\Ic;
use app\models\NfcCard;
use app\models\NfcAllocation;
use kartik\depdrop\DepDrop;
use yii\widgets\LinkPager;
use yii\helpers\Json;
use yii\widgets\Pjax;
use kartik\select2\Select2;

/* @var $this yii\web\View */
/* @var $searchModel app\models\TimeLogSearch */
/* @var $dataProvider yii\data\ActiveDataProvider */
/* @var $model app\models\NfcCardDetails */
/* @var $results array */

$this->title = 'NFC Card Report';
$this->params['breadcrumbs'][] = $this->title;
?>

<div class="time-log-index">

    <?php Pjax::begin(['id' => 'time-log-pjax']); ?>

    <?php $form = ActiveForm::begin(['id' => 'search-form']); ?>

    <div class="mt-bootstrap-tables">
        <div class="portlet light">
            <div class="portlet-title">
                <div class="caption">
                    <span class="caption-subject font-dark bold uppercase"><?= Html::encode($this->title) ?></span>
                </div>
                <div class="actions">
                    <?= Html::resetButton('Reset', ['class' => 'btn btn-default', 'onclick' => 'resetForm()']) ?>
                </div>
            </div>

            <div class="portlet-body" style="margin-top: 26px;">
                <form role="form">
                    <div class="row">
                        <div class="col-md-1 pull-right">
                            <?= Html::submitButton('Search', ['class' => 'btn btn-success']) ?>
                        </div>
                        <?php if ($results): ?>
                        <div class="actions" style="float:right;">
                            <div class="btn-group">
                                <a class="btn blue btn-outline btn-circle btn-sm" href="javascript:;" data-toggle="dropdown" data-hover="dropdown" data-close-others="true" aria-expanded="false">
                                    Export <i class="fa fa-angle-down"></i>
                                </a>
                                <ul class="dropdown-menu pull-right" style="min-width: 80px;">
                                    <li><a href="#" onclick="sendPdf()">Pdf</a></li>
                                    <li><a href="#" onclick="sendExcel()" target="_blank">Excel</a></li>
                                </ul>
                            </div>
                        </div>
                        <?php endif; ?>
                    </div>

                    <div class="row">
                    <div class="col-md-4">
                            <?= $form->field($model, 'region')->widget(Select2::classname(), [
                                'data' => Region::getRegionWithDefault(),
                                'options' => ['id' => 'region-dropdown', 'prompt' => 'Select Region'],
                                'pluginOptions' => [
                                    'allowClear' => true,
                                ],
                                'pluginEvents' => [
                                    'change' => 'function() {
                                        var regionId = $(this).val();
                                        if (regionId === "") {
                                            $("select#ic-dropdown").html("<option value=\'\'>Select IC</option>");
                                        } else {
                                            $.post(
                                                "' . Yii::$app->urlManager->createUrl('ic/ic-list?region_id=') . '"+regionId, 
                                                function(data) {
                                                    $("select#ic-dropdown").html(data);
                                                }
                                            );
                                        }
                                    }'
                                ],
                            ]); ?>
                        </div>
                        <div class="col-md-4">
                                <?= $form->field($model, 'ic')->widget(Select2::classname(), [
                                    'data' => $icOptions, // Preloaded IC options,
                                    'options' => [
                                        'id' => 'ic-dropdown',
                                        'prompt' => 'Select IC',
                                    ],
                                    'pluginOptions' => [
                                        'allowClear' => true,
                                    ],
                                ]); ?>
                            </div>
                    </div>

                    <br><br>
                </form>
            </div>
        </div>
    </div>

    <?php ActiveForm::end(); ?>

    <?php if ($results): ?>
        <br>
        <table id="results-table" class="table tableCompany_View-striped table-bordered table-advance table-hover">
            <thead>
                <tr>
                    <th scope="col"><b>Card Serial</b></th>
                    <th scope="col"><b>UID</b></th>
                    <th scope="col"><b>Allocation</b></th>
                    <th scope="col"><b>Interchange</b></th>
                    <th scope="col"><b>Expressway</b></th>
                    <th scope="col"><b>Remarks</b></th>
                    <th scope="col"><b>Last updated by</b></th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($results as $result): ?>
                <tr>
                    <td><?= $result['Card_Serial']; ?></td>
                    <td><?= $result['User_ID']; ?></td>
                    <td><?= $result['Allocation']; ?></td>
                    <td><?= $result['Interchange']; ?></td>
                    <td><?= $result['Expressway']; ?></td>
                    <td><?= $result['Remarks']; ?></td>
                    <td><?= $result['Last_Updated_By']; ?></td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    <?php else: ?>
        <!-- <p>No results found!</p> -->
    <?php endif; ?>

    <?php Pjax::end(); ?>

</div>

<style>
    .top-border {
        border-top: 2px solid #cccccc !important;
        border-left: 2px solid #cccccc !important;
        border-right: 2px solid #cccccc !important;
        background-color: #fff3cd;
        font-weight: bold;
        text-align: right;
    }
    .bottom-border {
        border-bottom: 2px solid #cccccc !important;
        border-left: 2px solid #cccccc !important;
        border-right: 2px solid #cccccc !important;
        background-color: #d1ecf1;
        text-align: right;
        font-weight: bold;
    }
    .specific-column {
        background-color: #f5c6cb !important;
        border: 2px solid #cccccc !important;
    }
    .grand_total {
        text-align: right;
        font-weight: bold;
    }
    th {
        text-align: center;
    }
    .my-custom-scrollbar {
        position: relative;
        height: 500px;
        overflow: auto;
    }
    .table-wrapper-scroll-y {
        display: block;
    }
    #entranceSearch {
        padding: 5px;
        border: 1px solid #ddd;
        margin: -5px;
        width: -webkit-fill-available;
    }
</style>

<script>
function sendPdf() {
    var model = <?= Json::encode($model); ?>;
    var results = <?= Json::encode($results); ?>;
    var url = '<?= Url::to(['reports/nfc-card-report-pdf']); ?>';
    gotoUrl(url, {
        'model': model,
        'results': results
    });
}

function sendExcel() {
    var model = <?= Json::encode($model); ?>;
    var results = <?= Json::encode($results); ?>;
    var url = '<?= Url::to(['reports/nfc-card-report-excel']); ?>';
    gotoUrl(url, {
        'model': model,
        'results': results
    });
}

function gotoUrl(path, params, method) {
    method = method || "post";
    var form = document.createElement("form");
    form.setAttribute("method", method);
    form.setAttribute("action", path);

    if (typeof params === 'string') {
        var hiddenField = document.createElement("input");
        hiddenField.setAttribute("type", "hidden");
        hiddenField.setAttribute("name", 'data');
        hiddenField.setAttribute("value", params);
        form.appendChild(hiddenField);
    } else {
        for (var key in params) {
            if (params.hasOwnProperty(key)) {
                var hiddenField = document.createElement("input");
                hiddenField.setAttribute("type", "hidden");
                hiddenField.setAttribute("name", key);
                hiddenField.setAttribute("value", JSON.stringify(params[key]));
                form.appendChild(hiddenField);
            }
        }
    }
    form.target = '_blank';
    document.body.appendChild(form);
    form.submit();
    return false;
}

function resetForm() {
    // Reset form fields
    $('#search-form')[0].reset();
    $('#region-dropdown').val('').trigger('change');
    $('#ic-dropdown').val('').trigger('change');
    $('#<?= Html::getInputId($model, 'designation') ?>').val('').trigger('change');
    $('#<?= Html::getInputId($model, 'role') ?>').val('').trigger('change');
    $('#<?= Html::getInputId($model, 'status') ?>').val('').trigger('change');

    // Reset displayed results
    $('#results-table').html('');

    // Reset Pjax content
    $.pjax.reload({container: '#time-log-pjax', async: false});

    // Refresh the entire page
    location.reload();
}
</script>
