<?php

use yii\helpers\Html;
use yii\grid\GridView;
use yii\widgets\ActiveForm;
use yii\helpers\ArrayHelper;
use yii\helpers\Url;
use yii\bootstrap4\Modal;
use kartik\date\DatePicker;
use app\models\Region;
use app\models\Ic;
use app\models\Designation;
use webvimark\modules\UserManagement\models\User;
use webvimark\modules\UserManagement\models\rbacDB\Role;
use kartik\depdrop\DepDrop;
use yii\widgets\LinkPager;
use yii\helpers\Json;
use yii\widgets\Pjax;
use kartik\select2\Select2;

/* @var $this yii\web\View */
/* @var $searchModel app\models\TimeLogSearch */
/* @var $dataProvider yii\data\ActiveDataProvider */

$this->title = 'User Details Report';
$this->params['breadcrumbs'][] = $this->title;
?>

<div class="time-log-index">

<?php Pjax::begin(['id' => 'time-log-pjax']); ?>

   
<?php $form = ActiveForm::begin([
    'id' => 'search-form',
    'enableClientValidation' => true,
    'enableAjaxValidation' => false,
    'options' => ['data-pjax' => true], 
]);?>

    <div class="mt-bootstrap-tables">
        <div>
            <div class="portlet light ">

                <div class="portlet-title">
                    <div class="caption">
                        <span class="caption-subject font-dark bold uppercase">
                            <?= Html::encode($this->title) ?></span>
                    </div>
                    <div class="actions">
                        <!-- Reset Button -->
                        <?= Html::resetButton('Reset', ['class' => 'btn btn-default', 'onclick' => 'resetForm()']) ?>
                    </div>
                </div>

                <div class="portlet-body" style="margin-top: 26px;">
                    <form role="form">
                        <div class="row">
                            <div class="col-md-1 pull-right">
                                <?= Html::submitButton('Search', ['class' => 'btn btn-success']) ?>
                            </div>
                            <?php if ($results): ?>
                            <div class="actions" style="float:right;">
                                <div class="btn-group">
                                    <a class="btn blue btn-outline btn-circle btn-sm" href="javascript:;"
                                        data-toggle="dropdown" data-hover="dropdown" data-close-others="true"
                                        aria-expanded="false"> Export
                                        <i class="fa fa-angle-down"></i>
                                    </a>
                                    <ul class="dropdown-menu pull-right" style="min-width: 80px;">
                                        <li>
                                            <a href="#" onclick="sendPdf('<?php echo $results; ?>')"> Pdf </a>
                                        </li>
                                        <li>
                                            <a href="#" onclick="sendExcel()" target="_blank">Excel </a>
                                        </li>
                                    </ul>
                                </div>
                            </div>
                            <?php endif; ?>
                        </div>

                        <div class="row">
                            <div class="col-md-4">
                                <?= $form->field($model, 'region')->widget(Select2::classname(), [
                                    'data' => Region::getRegionWithDefault(),
                                    'options' => [
                                        'prompt' => 'Select Region',
                                        'id' => 'region-dropdown',
                                    ],
                                    'pluginOptions' => [
                                        'allowClear' => true,
                                    ],
                                    'pluginEvents' => [
                                        'change' => '
                                            function() {
                                                var regionId = $(this).val();
                                                if (regionId === "") {
                                                    $("select#ic-dropdown").html("<option value=\'\'>Select IC</option>");
                                                } else {
                                                    $.post(
                                                        "' . Yii::$app->urlManager->createUrl('ic/ic-list?region_id=') . '"+regionId, 
                                                        function(data) {
                                                            $("select#ic-dropdown").html(data);
                                                        }
                                                    );
                                                }
                                            }
                                        ',
                                    ],
                                ]); ?>
                            </div>

                            <div class="col-md-4">
                                <?= $form->field($model, 'ic')->widget(Select2::classname(), [
                                    'data' => [],
                                    'options' => [
                                        'id' => 'ic-dropdown',
                                        'prompt' => 'Select IC',
                                    ],
                                    'pluginOptions' => [
                                        'allowClear' => true,
                                    ],
                                ]); ?>
                            </div>

                            <div class="col-md-4">
                                <?= $form->field($model, 'designation')->widget(Select2::classname(), [
                                    'data' => Designation::getDesignationWithDefault(),
                                    'options' => [
                                        'prompt' => 'Select Designation',
                                    ],
                                    'pluginOptions' => [
                                        'allowClear' => true,
                                    ],
                                ]); ?>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-4">
                                <?php
                                $anyOption = ['any' => 'Any'];
                                $roles = ArrayHelper::map(Role::getAvailableRoles(true, false), 'name', 'description');
                                $options = array_merge($anyOption, $roles);
                                ?>
                                <?= $form->field($model, 'role')->widget(Select2::classname(), [
                                    'data' => $options,
                                    'options' => [
                                        'prompt' => 'Select Role',
                                    ],
                                    'pluginOptions' => [
                                        'allowClear' => true,
                                    ],
                                ]); ?>
                            </div>

                            <div class="col-md-4">
                                <?= $form->field($model, 'status')->widget(Select2::classname(), [
                                    'data' => User::getStatusListWithDefault(),
                                    'options' => [
                                        'prompt' => 'Select Status',
                                    ],
                                    'pluginOptions' => [
                                        'allowClear' => true,
                                    ],
                                ]); ?>
                            </div>
                        </div>

                        <br>
                        <br>
                    </form>
                </div>
            </div>
        </div>
    </div>
    <?php ActiveForm::end(); ?>

    <?php print_r($results);die;if ($results): ?>
    <br>
    <table id="results-table" class="table tableCompany_View-striped table-bordered table-advance table-hover">
        <thead>
            <tr>
                <th scope="col"><b>User Name</b></th>
                <th scope="col"><b>Designation</b></th>
                <th scope="col"><b>Super Admin (Yes/No)</b></th>
                <th scope="col"><b>Role</b></th>
                <th scope="col"><b>Expressway</b></th>
                <th scope="col"><b>Interchange</b></th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($results as $result):?> 
                <tr>
                    <td><?php echo $result['UserName']; ?></td>
                    <td><?php echo $result['Designation']; ?></td>
                    <td><?php echo $result['SuperAdmin'] ? 'Yes' : 'No'; ?></td>
                    <td><?php echo $result['role']; ?></td>
                    <td><?php echo $result['Expressway']; ?></td>
                    <td><?php echo $result['Interchange']; ?></td>
                </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
    <?php else: ?>
        <p>No results found!</p>
    <?php endif; ?>

    <?php Pjax::end(); ?>

</div>

<style>
.top-border {
    border-top: 2px solid #cccccc !important;
    border-left: 2px solid #cccccc !important;
    border-right: 2px solid #cccccc !important;
    background-color: #fff3cd;
    padding: 1px !important;
    font-weight: bold;
    text-align: right;
}

.bottom-border {
    border-bottom: 2px solid #cccccc !important;
    border-left: 2px solid #cccccc !important;
    border-right: 2px solid #cccccc !important;
    background-color: #d1ecf1;
    padding: 1px !important;
    text-align: right;
    font-weight: bold;
}

.specific-column {
    background-color: #f5c6cb !important;
    border: 2px solid #cccccc !important;
}

.grand_total {
    text-align: right;
    font-weight: bold;
}

th {
    text-align: center;
}

.my-custom-scrollbar {
    position: relative;
    height: 500px;
    overflow: auto;
}

.table-wrapper-scroll-y {
    display: block;
}

#entranceSearch {
    padding: 5px 5px 5px 5px;
    border: 1px solid #ddd;
    margin: -5px;
    width: -webkit-fill-available;
}
</style>
<script>
    function sendPdf(a) {
        
        console.log("data",a);
        var model = <?php echo Json::encode($model); ?>;
        var results = <?php echo Json::encode($results); ?>;
        console.log("Hello world!");
        
        var url = '<?php echo Url::to(['reports/user-details-report-pdf']); ?>';
        gotoUrl(url, {
            'model': model,
            'results': results
        });
        
    }

    function sendExcel() {
        var model = <?php echo Json::encode($model); ?>;
        var results = <?php echo Json::encode($results); ?>;
        var url = '<?php echo Url::to(['reports/user-details-report-excel']); ?>';
        gotoUrl(url, {
            'model': model,
            'results': results
        });
    }

    function gotoUrl(path, params, method) {
        method = method || "post";

        var form = document.createElement("form");
        form.setAttribute("method", method);
        form.setAttribute("action", path);

        if (typeof params === 'string') {
            var hiddenField = document.createElement("input");
            hiddenField.setAttribute("type", "hidden");
            hiddenField.setAttribute("name", 'data');
            hiddenField.setAttribute("value", params);
            form.appendChild(hiddenField);
        } else {
            for (var key in params) {
                if (params.hasOwnProperty(key)) {
                    var hiddenField = document.createElement("input");
                    hiddenField.setAttribute("type", "hidden");
                    hiddenField.setAttribute("name", key);
                    hiddenField.setAttribute("value", typeof params[key] === 'object' ? JSON.stringify(params[key]) : params[key]);
                    form.appendChild(hiddenField);
                }
            }
        }
        form.target = '_blank';
        document.body.appendChild(form);
        form.submit();
        return false;
    }

    function resetForm() {
        $('#search-form')[0].reset();

        $('#region-dropdown').val('').trigger('change');
        $('#ic-dropdown').val('').trigger('change');
        $('#<?= Html::getInputId($model, 'designation') ?>').val('').trigger('change');
        $('#<?= Html::getInputId($model, 'role') ?>').val('').trigger('change');
        $('#<?= Html::getInputId($model, 'status') ?>').val('').trigger('change');

        $('#results-table').html('');

        $.pjax.reload({container: '#time-log-pjax', async: false});

        location.reload();
    }
</script>

