<?php

use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use PhpOffice\PhpSpreadsheet\Style\Border;
use PhpOffice\PhpSpreadsheet\Style\Fill;
use app\models\Ic;
use webvimark\modules\UserManagement\models\User;

// Create a new spreadsheet
$spreadsheet = new Spreadsheet();
$sheet = $spreadsheet->getActiveSheet();
$sheet->setTitle('XLSX Document');

$nowdate = date('Y.m.d.h.i.s');

// Define styles
$styleArrayHeading = [
    'font' => [
        'bold' => true,
        'color' => ['rgb' => '307BBA'],
        'size' => 8,
        'name' => 'Verdana'
    ],
];

$styleArrayTitle = [
    'font' => [
        'bold' => true,
        'color' => ['rgb' => '4040C4'],
        'size' => 8,
        'name' => 'Verdana'
    ]
];

$styleArrayTotal = [
    'font' => [
        'bold' => true,
        'color' => ['rgb' => '000000'],
        'size' => 8,
        'name' => 'Verdana'
    ]
];

$styleArrayBorder = [
    'borders' => [
        'allBorders' => [
            'borderStyle' => Border::BORDER_THIN,
            'color' => ['rgb' => '000000']
        ],
    ],
];

// Set column widths
$columns = ['A' => 20, 'B' => 20, 'C' => 20, 'D' => 20, 'E' => 20, 'F' => 20];
foreach ($columns as $column => $width) {
    $sheet->getColumnDimension($column)->setWidth($width);
}

// Set header values
$count = 1;
$sheet->setCellValue('A' . $count++, 'USER DETAILS REPORT');
$sheet->setCellValue('A' . $count++, 'GENERATED DATE: ' . $nowdate);
$sheet->setCellValue('A' . $count++, 'USER: ' . Yii::$app->getUser()->identity->username);
$sheet->setCellValue('A' . $count++, $model['ic'] == 'Any' ? 'IC: Any' : 'IC: ' . Ic::findOne($model['ic'])->name);
$count++;

// Set table headers
$headers = ['UserName', 'Designation', 'SuperAdmin', 'Role', 'Expressway', 'Interchange'];
$colIndex = 1;
foreach ($headers as $header) {
    $sheet->setCellValueByColumnAndRow($colIndex++, $count, $header);
}
$sheet->getStyle('A' . $count . ':F' . $count)->applyFromArray($styleArrayHeading);
$sheet->getStyle('A' . $count . ':F' . $count)->getFill()
    ->setFillType(Fill::FILL_SOLID)
    ->getStartColor()->setARGB('a3c2c2');

$count++;

// Fill data
foreach ($results as $result) {
    $rowIndex = 1;
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['UserName']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['Designation']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['SuperAdmin'] ? 'Yes' : 'No');
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['role']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['Expressway']);
    $sheet->setCellValueByColumnAndRow($rowIndex++, $count, $result['Interchange']);
    $count++;
}

// Apply border style to data range
$sheet->getStyle('A' . ($count - count($results) - 1) . ':F' . ($count - 1))->applyFromArray($styleArrayBorder);

// Output the Excel file
$filename = 'USER_DETAILS_REPORT_' . date('Y-m-d-H-i-s') . '.xlsx';
header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
header('Content-Disposition: attachment;filename="' . $filename . '"');
header('Cache-Control: max-age=0');

$writer = new Xlsx($spreadsheet);
$writer->save('php://output');
exit;
?>
